@@ -1,4 +1,5 @@
 //! CKB chain service.
+#![allow(missing_docs)]
 
 use ckb_channel::{self as channel, select, Sender};
 use ckb_error::{Error, InternalErrorKind};
@@ -35,6 +36,7 @@ type TruncateRequest = Request<Byte32, Result<(), Error>>;
 /// The controller is internally reference-counted and can be freely cloned.
 ///
 /// A controller can invoke [`ChainService`] methods.
+#[cfg_attr(feature = "mock", faux::create)]
 #[derive(Clone)]
 pub struct ChainController {
     process_block_sender: Sender<ProcessBlockRequest>,
@@ -44,11 +46,23 @@ pub struct ChainController {
 
 impl Drop for ChainController {
     fn drop(&mut self) {
-        self.stop.try_send();
+        self.stop();
     }
 }
 
+#[cfg_attr(feature = "mock", faux::methods)]
 impl ChainController {
+    pub fn new(
+        process_block_sender: Sender<ProcessBlockRequest>,
+        truncate_sender: Sender<TruncateRequest>,
+        stop: StopHandler<()>,
+    ) -> Self {
+        ChainController {
+            process_block_sender,
+            truncate_sender,
+            stop,
+        }
+    }
     /// Inserts the block into database.
     ///
     /// Expects the block's header to be valid and already verified.
@@ -85,6 +99,10 @@ impl ChainController {
                 .into())
         })
     }
+
+    pub fn stop(&mut self) {
+        self.stop.try_send();
+    }
 }
 
 /// The struct represent fork
@@ -218,11 +236,7 @@ impl ChainService {
             .expect("Start ChainService failed");
         let stop = StopHandler::new(SignalSender::Crossbeam(signal_sender), Some(thread));
 
-        ChainController {
-            process_block_sender,
-            truncate_sender,
-            stop,
-        }
+        ChainController::new(process_block_sender, truncate_sender, stop)
     }
 
     fn make_fork_for_truncate(&self, target: &HeaderView, current_tip: &HeaderView) -> ForkChanges {
@@ -806,12 +820,9 @@ impl ChainService {
         let bottom = tip_number - cmp::min(tip_number, len);
 
         for number in (bottom..=tip_number).rev() {
-            let hash = snapshot.get_block_hash(number).unwrap_or_else(|| {
-                panic!(format!(
-                    "invaild block number({}), tip={}",
-                    number, tip_number
-                ))
-            });
+            let hash = snapshot
+                .get_block_hash(number)
+                .unwrap_or_else(|| panic!("invaild block number({}), tip={}", number, tip_number));
             debug!("   {} => {}", number, hash);
         }
 
